@@ -11,7 +11,7 @@ except ImportError:
 
 def _resize_pillow(src, height, width, interpolation):
     if interpolation == "linear":
-        interpolation = PIL.Image.LINEAR
+        interpolation = PIL.Image.BILINEAR
     elif interpolation == "nearest":
         interpolation = PIL.Image.NEAREST
     else:
@@ -32,9 +32,7 @@ def _resize_pillow(src, height, width, interpolation):
         for c in range(C):
             src_c = src[:, :, c]
             src_c = utils.numpy_to_pillow(src_c)
-            dst[:, :, c] = src_c.resize(
-                (width, height), resample=interpolation
-            )
+            dst[:, :, c] = src_c.resize((width, height), resample=interpolation)
 
         if ndim == 2:
             dst = dst[:, :, 0]
